Enum syntex_syntax::ast::PatKind
[−]
[src]
pub enum PatKind {
Wild,
Ident(BindingMode, SpannedIdent, Option<P<Pat>>),
Struct(Path, Vec<Spanned<FieldPat>>, bool),
TupleStruct(Path, Option<Vec<P<Pat>>>),
Path(Path),
QPath(QSelf, Path),
Tup(Vec<P<Pat>>),
Box(P<Pat>),
Ref(P<Pat>, Mutability),
Lit(P<Expr>),
Range(P<Expr>, P<Expr>),
Vec(Vec<P<Pat>>, Option<P<Pat>>, Vec<P<Pat>>),
Mac(Mac),
}Variants
Wild | Represents a wildcard pattern ( | |
Ident | A In the unit or const pattern case, the parser can't determine
which it is. The resolver determines this, and
records this pattern's | |
Struct | A struct or struct variant pattern, e.g. | |
TupleStruct | A tuple struct/variant pattern | |
Path | A path pattern. Such pattern can be resolved to a unit struct/variant or a constant. | |
QPath | An associated const named using the qualified path | |
Tup | A tuple pattern | |
Box | A | |
Ref | A reference pattern, e.g. | |
Lit | A literal | |
Range | A range pattern, e.g. | |
Vec |
| |
Mac | A macro pattern; pre-expansion |